pub(crate) fn add_spawned_entity(
world: &Arc<World>,
entity: SharedEntity,
) -> Result<(), AddEntityError>Expand description
Inserts a fully initialized entity into the live world entity manager.
pub(crate) fn add_spawned_entity(
world: &Arc<World>,
entity: SharedEntity,
) -> Result<(), AddEntityError>Inserts a fully initialized entity into the live world entity manager.