pub(crate) fn apply_implicit_item_stack_components(
entity: &SharedEntity,
item_stack: &ItemStack,
)Expand description
Applies the implicit entity data carried by an item stack.
pub(crate) fn apply_implicit_item_stack_components(
entity: &SharedEntity,
item_stack: &ItemStack,
)Applies the implicit entity data carried by an item stack.